/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_DIPROPERTIES_TEST_H_
#define _GB2_DIPROPERTIES_TEST_H_

#include "DIPropertiesSitecon.h"
#include <test_framework/xmltest/XMLTestUtils.h>
#include <core_api/GObject.h>
#include <QtXml/QDomElement>

namespace GB2 {

class GTest_DiPropertySiteconCheckAttribs : public GTest {
    Q_OBJECT
public:
    SIMPLE_XML_TEST_BODY_WITH_FACTORY(GTest_DiPropertySiteconCheckAttribs, "sitecon-check_diproperty_attrib");

    Task::ReportResult report();
private:
    DinucleotitePropertyRegistry result;
    QString key;
    QString val;
    int expAve;
    int expSdev;
};

}//ns

#endif
